OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Nhãn",
    "Update" : "Cập nhật",
    "Create" : "Tạo",
    "Select tag…" : "Chọn nhãn...",
    "Added system tag {systemtag}" : "Nhãn hệ thống được thêm vào {systemtag}",
    "Added system tag %1$s" : "Đã thêm nhãn hệ thống %1$s",
    "%1$s added system tag %2$s" : "%1$s đã thêm nhãn hệ thống %2$s",
    "{actor} added system tag {systemtag}" : "{actor} đã thêm nhãn hệ thống {systemtag}",
    "Removed system tag {systemtag}" : "Đã xóa nhãn hệ thống {systemtag}",
    "Removed system tag %1$s" : "Đã xóa nhãn hệ thống %1$s",
    "%1$s removed system tag %2$s" : "%1$s đã xóa nhãn hệ thống %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} đã xóa nhãn {systemtag}",
    "You created system tag %1$s" : "Bạn đã tạo nhãn %1$s",
    "You created system tag {systemtag}" : "Bạn đã tạo nhãn {systemtag}",
    "%1$s created system tag %2$s" : "%1$s đã tạo nhãn %2$s",
    "{actor} created system tag {systemtag}" : "{actor} đã tạo nhãn {systemtag}",
    "You deleted system tag %1$s" : "Bạn đã xóa nhãn %1$s",
    "You deleted system tag {systemtag}" : "Bạn đã xóa nhãn {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s đã xóa nhãn %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} đã xóa nhãn {systemtag}",
    "You updated system tag %2$s to %1$s" : "Bạn đã cập nhật nhãn %2$s to %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Bạn đã cập nhật nhãn {oldsystemtag} thành {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s đã cập nhật nhãn %3$s thành%2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} đã cập nhật nhãn {oldsystemtag} thành {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Bạn đã dán nhãn %2$s vào %1$s",
    "You added system tag {systemtag} to {file}" : "Bạn đã dán nhãn {systemtag} vào {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s đã dán nhãn %3$s vào %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} đã dán nhãn {systemtag} vào {file}",
    "You removed system tag %2$s from %1$s" : "Bạn đã xóa nhãn %2$s khỏi %1$s",
    "You removed system tag {systemtag} from {file}" : "Bạn đã xóa nhãn {systemtag} khỏi {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s đã xóa nhãn %3$s khỏi %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} đã xóa nhãn {systemtag} khỏi {file}",
    "%s (restricted)" : "%s (bị hạn chế)",
    "%s (invisible)" : "%s (vô hình)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Nhãn</strong> cho một tập tin đã được sửa đổi",
    "Collaborative tags" : "Thẻ cộng tác",
    "Tagged files" : "Các tệp được dán nhãn",
    "Select tags to filter by" : "Chọn nhãn để lọc theo",
    "No tags found" : "Không tìm thấy nhãn",
    "Please select tags to filter by" : "Vui lòng chọn các nhãn để lọc theo",
    "No files found for the selected tags" : "Không tìm thấy tệp cho các nhãn đã chọn",
    "Select tag …" : "Lựa chọn thẻ",
    "Name" : "Tên",
    "Public" : "Công khai",
    "Restricted" : "Bị giới hạn",
    "Invisible" : "Vô hình",
    "Delete" : "Xóa bỏ",
    "Reset" : "Đặt lại",
    "No files in here" : "Không có tệp ở đây",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi"
},
"nplurals=1; plural=0;");
